@@ -151,7 +151,7 @@ The channel for the nopaste, not always relevant. Usually tied to a pastebot in
 
 =head2 -s, --services
 
-The nopaste services to try, in order. You may also specify this in C<$NOPASTE_SERVICES> (space-separated list of service names, e.g. C<Husk ShadowCat Rafb>).
+The nopaste services to try, in order. You may also specify this in C<$NOPASTE_SERVICES> (space-separated list of service names, e.g. C<Husk Shadowcat Rafb>).
 
 =head2 -x, --copy
 
